ErrnoSentinel

Trait ErrnoSentinel 

pub trait ErrnoSentinel: Sized {
    // Required method
    fn sentinel() -> Self;
}
The sentinel value indicates that a function failed and more detailed information about the error can be found in errno

Required Methods

fn sentinel() -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ErrnoSentinel for *mut c_void

Source

fn sentinel() -> Self

Source

impl ErrnoSentinel for i32

Source

fn sentinel() -> Self

Source

impl ErrnoSentinel for i64

Source

fn sentinel() -> Self

Source

impl ErrnoSentinel for isize

Source

fn sentinel() -> Self

Source

impl ErrnoSentinel for sighandler_t

Source

fn sentinel() -> Self

Implementors